<?php

/**
 * @file
 * Install Profile for DrupalBin - http://drupalbin.com 
 */
 
/**
 * Return an array of the modules to be enabled when this profile is installed.
 *
 * @return
 *  An array of modules to be enabled.
 */
function drupalbin_profile_modules() {
  return array(
    // Core - required
    'block', 'filter', 'node', 'system', 'user',

    // Core - optional
    'color', 'help', 'menu', 'path', 'search', 'taxonomy',

    // GeSHi Filter
    'geshifilter', 'geshinode',
    
    // Other
    'token', 'pathauto', 'auto_nodetitle', 'clone', 'print'
  );
}

/**
 * Return a description of the profile for the initial installation screen.
 *
 * @return
 *   An array with keys 'name' and 'description' describing this profile.
 */
function drupalbin_profile_details() {
  return array(
    'name' => 'DrupalBin',
    'description' => 'Tool to collaborate and debug code snippets.'
  );
}

/**
 * Return a list of tasks that this profile supports.
 *
 * @return
 *   A keyed array of tasks the profile will perform during
 *   the final stage. The keys of the array will be used internally,
 *   while the values will be displayed to the user in the installer
 *   task list.
 */
function drupalbin_profile_task_list() {
}


/**
 * Perform any final installation tasks for this profile.
 *
 * @param $task
 *   The current $task of the install system. When hook_profile_tasks()
 *   is first called, this is 'profile'.
 * @param $url
 *   Complete URL to be used for a link or form action on a custom page,
 *   if providing any, to allow the user to proceed with the installation.
 *
 * @return
 *   An optional HTML string to display to the user. Only used if you
 *   modify the $task, otherwise discarded.
 */
function drupalbin_profile_tasks(&$task, $url) {
  // Site information
  variable_set('site_mission', 'Post a code snippet.');
  variable_set('site_frontpage', 'node/add/geshinode');
  
  // Permissions
  db_query("UPDATE {permission} SET perm = '%s' WHERE rid = %d",
    'create source code node, access content, clone node, search content', 1);
  db_query("UPDATE {permission} SET perm = '%s' WHERE rid = %d",
    'create source code node, edit own source code node, access content, clone node, search content', 2);
  
  // Taxonomy
  $tags = array(
    'name' => 'Tags',
    'help' => 'Any tags you would like to associate with your code, delimitered by commas (example: Views, CCK, Module, etc).',
    'relations' => '0',
    'hierarchy' => '1',
    'multiple' => '0',
    'required' => '0',
    'tags' => '1',
    'module' => 'taxonomy',
    'weight' => '0',
    'nodes' => array('geshinode' => 'geshinode')
  );
  taxonomy_save_vocabulary($tags);
  
  // PathAuto
  variable_set('pathauto_node_geshinode_pattern', '[nid]');
  
  // Automatic Node Titles
  variable_set('ant_geshinode', '2');
  variable_set('ant_pattern_geshinode', 'Code');

  // Geshi library config
  variable_set('geshifilter_geshi_dir','profiles/drupalbin/libraries/geshi');

  // String Overrides
  variable_set('locale_custom_strings_en',
    array(
      'Printer-friendly version' => 'Download',
      'Clone' => 'Fix',
    )
  );
}
